@@ -1,10 +1,11 @@
 #!/usr/bin/perl
 
-# $Id: Transport.pm,v 1.22 2003/07/01 16:41:50 unimlo Exp $
+# $Id: Transport.pm,v 1.25 2003/10/27 23:57:55 unimlo Exp $
 
 package Net::BGP::Transport;
 
 use strict;
+use Errno qw(EAGAIN);
 use vars qw(
     $VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS @BGP @GENERIC
     @BGP_EVENT_MESSAGE_MAP @BGP_EVENTS @BGP_FSM @BGP_STATES
@@ -13,7 +14,7 @@ use vars qw(
 ## Inheritance and Versioning ##
 
 @ISA     = qw( Exporter );
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 ## General Definitions ##
 
@@ -206,6 +207,7 @@ use Errno qw(EINPROGRESS ENOTCONN);
 use Exporter;
 use IO::Socket;
 use Carp;
+use Carp qw(cluck);
 use Net::BGP::Notification qw( :errors );
 use Net::BGP::Refresh;
 use Net::BGP::Update;
@@ -571,7 +573,7 @@ sub _send_msg
 
     unless (defined $this->{_peer_socket}) {
         return if $oktofail;
-        warn $this->parent->asstring . ": Internal error - no _peer_socket - Connection is shutdown\n";
+        cluck $this->parent->asstring . ": Internal error - no _peer_socket - Connection is shutdown\n";
         $this->_cease;
         return;
     }
@@ -581,8 +583,10 @@ sub _send_msg
 
     if ( ! defined($sent) ) {
         return if $oktofail; # In a _cease process - Don't complain...
-        warn $this->parent->asstring . ": Error on socket write: $! - Connection is shutdown\n";
-        $this->_cease;
+	if ($!{EAGAIN} == 0) {
+	    warn $this->parent->asstring . ": Error on socket write: $! - Connection is shutdown\n";
+            $this->_cease;
+	}
         return;
     }
 
@@ -618,7 +622,7 @@ sub _handle_socket_read_ready
         }
         elsif ( $num_read != BGP_MESSAGE_HEADER_LENGTH ) {
             $this->{_in_msg_buf_state} = AWAITING_HEADER_FRAGMENT;
-            $this->{_in_msg_buf_bytes_exp} = BGP_MESSAGE_HEADER_LENGTH - $num_read;
+            $this->{_in_msg_buf_bytes_exp} = (BGP_MESSAGE_HEADER_LENGTH) - ($num_read);
             $this->{_in_msg_buffer} = $buffer;
         }
         else {
